pub struct FvAttributes(/* private fields */);Expand description
EFI_FV_ATTRIBUTES
Implementations
Sourceimpl FvAttributes
impl FvAttributes
pub const READ_DISABLE_CAP: Self
pub const READ_ENABLE_CAP: Self
pub const READ_STATUS: Self
pub const WRITE_DISABLE_CAP: Self
pub const WRITE_ENABLE_CAP: Self
pub const WRITE_STATUS: Self
pub const LOCK_CAP: Self
pub const LOCK_STATUS: Self
pub const WRITE_POLICY_RELIABLE: Self
pub const READ_LOCK_CAP: Self
pub const READ_LOCK_STATUS: Self
pub const WRITE_LOCK_CAP: Self
pub const WRITE_LOCK_STATUS: Self
pub const ALIGNMENT: Self
pub const ALIGNMENT_1: Self
pub const ALIGNMENT_2: Self
pub const ALIGNMENT_4: Self
pub const ALIGNMENT_8: Self
pub const ALIGNMENT_16: Self
pub const ALIGNMENT_32: Self
pub const ALIGNMENT_64: Self
pub const ALIGNMENT_128: Self
pub const ALIGNMENT_256: Self
pub const ALIGNMENT_512: Self
pub const ALIGNMENT_1K: Self
pub const ALIGNMENT_2K: Self
pub const ALIGNMENT_4K: Self
pub const ALIGNMENT_8K: Self
pub const ALIGNMENT_16K: Self
pub const ALIGNMENT_32K: Self
pub const ALIGNMENT_64K: Self
pub const ALIGNMENT_128K: Self
pub const ALIGNMENT_256K: Self
pub const ALIGNMENT_512K: Self
pub const ALIGNMENT_1M: Self
pub const ALIGNMENT_2M: Self
pub const ALIGNMENT_4M: Self
pub const ALIGNMENT_8M: Self
pub const ALIGNMENT_16M: Self
pub const ALIGNMENT_32M: Self
pub const ALIGNMENT_64M: Self
pub const ALIGNMENT_128M: Self
pub const ALIGNMENT_256M: Self
pub const ALIGNMENT_512M: Self
pub const ALIGNMENT_1G: Self
pub const ALIGNMENT_2G: Self
Sourceimpl FvAttributes
impl FvAttributes
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl FvAttributes
impl FvAttributes
Sourcepub const fn iter(&self) -> Iter<FvAttributes>
pub const fn iter(&self) -> Iter<FvAttributes>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<FvAttributes>
pub const fn iter_names(&self) -> IterNames<FvAttributes>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.